@@ -3,7 +3,7 @@ package Function::Parameters::Info;
 use v5.14.0;
 use warnings;
 
-our $VERSION = '1.0701';
+our $VERSION = '1.0702';
 
 # If Moo isn't loaded yet but Moose is, avoid pulling in Moo and fall back to Moose
 my ($Moo, $meta_make_immutable);
@@ -111,7 +111,7 @@ methods are available:
 =head2 $info->invocant
 
 Returns the name of the variable into which the first argument is
-L<C<shift>|perlfunc/shift>ed automatically, or C<undef> if no such thing
+L<C<shift>|perlfunc/shift ARRAY>ed automatically, or C<undef> if no such thing
 exists. This will usually return C<'$self'> for methods.
 
 =head2 $info->positional_required
